@@ -3,10 +3,12 @@
 from .auth import Auth
 from .config import BY_PASS_LOGIN
 from .trainer import Trainer
+from .utils.general import colorstr
 from .yolov5_wrapper import clone_yolo
 
 AUTH = Auth()
 CONNECTED = False
+PREFIX = colorstr('Ultralytics: ')
 
 
 def train_model() -> None:
@@ -23,7 +25,7 @@ def connect_to_hub(password=False, verbose=False) -> bool:
     global CONNECTED
 
     if CONNECTED and verbose:
-        print(f'Already logged in.')
+        print(f'{PREFIX}Already logged in.')
     elif not CONNECTED:
         CONNECTED = AUTH.attempt_signin() if password else AUTH.attempt_api_key()
 
@@ -38,6 +40,6 @@ def main():
         if AUTH.idToken:
             train_model()
         else:
-            print("Incorrect Login Details.")
+            print(f"{PREFIX}Incorrect Login Details.")
     elif connect_to_hub():
         train_model()
